/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.fritzmeijer;

/**
 *  enum for defining fields in the crop circle files
 *  contains 'start' 'end' positions, mandatory length, mandatory and dat type
 *  the mandatory lenght is introduced due to the fact that fields could be negative and have a extra minus "-" character
 *  @author Gerben Feenstra
 */


public enum FritzMeijerFileDescription {
        /* Latitude of measured cropcircle coordinate */
        LATITUDE(0,12,true,java.lang.Double.class), 
        
        /* Longitude of measured cropcircle coordinate */
	LONGITUDE(1,12,true,java.lang.Double.class), 
        
        DATE(2, 8, true, java.util.Date.class),
        
        /* Time */
	TIME(3,8,true,java.util.Date.class),  
          
        /* Course */
	HEAD(4,1,true,java.lang.Double.class),
                
        /* Latitude of measured cropcircle coordinate */
        LAT_ORG(5,12,true,java.lang.Double.class), 
        
        /* Longitude of measured cropcircle coordinate */
	LON_ORG(6,12,true,java.lang.Double.class), 
        
        /* Height of the sensor in m */
	ALTITUDE(7,4,true,java.lang.Double.class),
                    
        /* Speed of vehicle at the moment this coordinate is measured. m/s */
	SPEED(8,3,true,java.lang.Double.class),
        
        /*  */
	FIXTYPE(9,1,true,java.lang.Integer.class), //1 4
        
        /* in nm */
        IRMI(10, 6, true, java.lang.Double.class),
        
        /* Biomassa en stikstof */
        TCARI(11, 5, true, java.lang.Double.class),
        
        /* Biomassa en stikstof */
        OSAVI(12, 5, true, java.lang.Double.class),
        
        /* */
        TC_OS(13, 5, true, java.lang.Double.class),
        
        /* Biomassa */
        WDVI(14, 5, true, java.lang.Double.class),
        
        /* */
        NDRE(15, 5, true, java.lang.Double.class);
        
	private final int position;
        private final int mandatoryLength;
	private final boolean mandatory;
	private final static String delimiter = ";";
        private final Class theClass;
	
	private FritzMeijerFileDescription(int position, int mandatoryLength, boolean mandatory, Class theClass ){
		this.position = position;
		this.mandatory = mandatory;
                this.mandatoryLength = mandatoryLength;
                this.theClass = theClass;
	}
	
	public static String getDelimiter() {
		return delimiter;
	}

	public int getPosition() {
		return position;
	}

	public boolean isMandatory() {
		return mandatory;
	}

        public int getMandatoryLength() {
            return mandatoryLength;
        }

        public Class getTheClass() {
            return theClass;
        }	
}
