/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.fritzmeijer;

import java.io.Serializable;
import java.util.Date;
import javax.persistence.Column;
import javax.persistence.DiscriminatorValue;
import javax.persistence.Entity;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import nl.cloudfarming.client.model.SensorData;

/**
 *
 * @author Gerben Feenstra
 */
@NamedQueries(value = {
    @NamedQuery(name = FritzMeijerSensorData.Q_FIND_ALL_FRITZMEIJER_SENSORDATA, query = "select f from FritzMeijerSensorData f")
})
@Entity
@DiscriminatorValue("fritzmeijer")
public class FritzMeijerSensorData extends SensorData implements Serializable {

    public static final String Q_FIND_ALL_FRITZMEIJER_SENSORDATA = "findAllFritzMeijerSensorData";
    @Column(name = "FIX_TYPE")
    private int fixType;
    @Column
    private Double altitude;
    @Temporal(TemporalType.DATE)
    @Column
    private Date ddate; // date is a reserved word
    @Column
    private Double latitudeOriginal;
    @Column
    private Double longitudeOriginal;
    @Column
    private Double irmi;
    @Column
    private Double tcari;
    @Column
    private Double osavi;
    @Column
    private Double tcOs;
    @Column
    private Double ndre;

    public Double getAltitude() {
        return altitude;
    }

    public void setAltitude(Double altitude) {
        this.altitude = altitude;
    }

    public Date getDdate() {
        return ddate;
    }

    public void setDdate(Date ddate) {
        this.ddate = ddate;
    }

    public int getFixType() {
        return fixType;
    }

    public void setFixType(int fixType) {
        this.fixType = fixType;
    }

    public Double getIrmi() {
        return irmi;
    }

    public void setIrmi(Double irmi) {
        this.irmi = irmi;
    }

    public Double getLatitudeOriginal() {
        return latitudeOriginal;
    }

    public void setLatitudeOriginal(Double latitudeOriginal) {
        this.latitudeOriginal = latitudeOriginal;
    }

    public Double getLongitudeOriginal() {
        return longitudeOriginal;
    }

    public void setLongitudeOriginal(Double longitudeOriginal) {
        this.longitudeOriginal = longitudeOriginal;
    }

    public Double getNdre() {
        return ndre;
    }

    public void setNdre(Double ndre) {
        this.ndre = ndre;
    }

    public Double getOsavi() {
        return osavi;
    }

    public void setOsavi(Double osavi) {
        this.osavi = osavi;
    }

    public Double getTcOs() {
        return tcOs;
    }

    public void setTcOs(Double tcOs) {
        this.tcOs = tcOs;
    }

    public Double getTcari() {
        return tcari;
    }

    public void setTcari(Double tcari) {
        this.tcari = tcari;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final FritzMeijerSensorData other = (FritzMeijerSensorData) obj;
        if (this.fixType != other.fixType) {
            return false;
        }
        if (this.altitude != other.altitude && (this.altitude == null || !this.altitude.equals(other.altitude))) {
            return false;
        }
        if (this.ddate != other.ddate && (this.ddate == null || !this.ddate.equals(other.ddate))) {
            return false;
        }
        if (this.latitudeOriginal != other.latitudeOriginal && (this.latitudeOriginal == null || !this.latitudeOriginal.equals(other.latitudeOriginal))) {
            return false;
        }
        if (this.longitudeOriginal != other.longitudeOriginal && (this.longitudeOriginal == null || !this.longitudeOriginal.equals(other.longitudeOriginal))) {
            return false;
        }
        if (this.irmi != other.irmi && (this.irmi == null || !this.irmi.equals(other.irmi))) {
            return false;
        }
        if (this.tcari != other.tcari && (this.tcari == null || !this.tcari.equals(other.tcari))) {
            return false;
        }
        if (this.osavi != other.osavi && (this.osavi == null || !this.osavi.equals(other.osavi))) {
            return false;
        }
        if (this.tcOs != other.tcOs && (this.tcOs == null || !this.tcOs.equals(other.tcOs))) {
            return false;
        }
        if (this.ndre != other.ndre && (this.ndre == null || !this.ndre.equals(other.ndre))) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = super.hashCode();
        hash = 47 * hash + this.fixType;
        hash = 47 * hash + (this.altitude != null ? this.altitude.hashCode() : 0);
        hash = 47 * hash + (this.ddate != null ? this.ddate.hashCode() : 0);
        hash = 47 * hash + (this.latitudeOriginal != null ? this.latitudeOriginal.hashCode() : 0);
        hash = 47 * hash + (this.longitudeOriginal != null ? this.longitudeOriginal.hashCode() : 0);
        hash = 47 * hash + (this.irmi != null ? this.irmi.hashCode() : 0);
        hash = 47 * hash + (this.tcari != null ? this.tcari.hashCode() : 0);
        hash = 47 * hash + (this.osavi != null ? this.osavi.hashCode() : 0);
        hash = 47 * hash + (this.tcOs != null ? this.tcOs.hashCode() : 0);
        hash = 47 * hash + (this.ndre != null ? this.ndre.hashCode() : 0);
        return hash;
    }
    
    
}
