/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.sensor.fritzmeijer;

import java.util.List;
import javax.persistence.Query;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;
import nl.cloudfarming.client.sensor.SensorModule;
import nl.cloudfarming.client.sensor.SensorService;
import org.openide.util.NbBundle;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Gerben Feenstra
 */
@ServiceProvider(service = FritzMeijerService.class)
public class FritzMeijerService extends SensorService {
    
    private static final AppLogger LOG = AppLogFactory.getLogger(FritzMeijerService.class);
    private static final String LOGKEY_PROCESSING_ERRORMSG = NbBundle.getMessage(SensorModule.class, "sensor.common.service.logerror.bulk_persist_error");
    
    @Override
    protected String getModuleName() {
        return FritzMeijerModule.MODULE_NAME;
    }

    /**
     * Method to bulk persist.
     * Clears the entitymanager after persisting. Only to be used in single thread.
     * WARNING all non persisted entity's will be cleared from the entitymanager !!!
     * @Return list<CropcircleSensorData>: returns the failing CropcircleSensorData's.
     * @param sensorDataList: List of CropcircleSensorData to bulkPersist
     * @param blockSize: the size of the blocks between persists
     */
    public void bulkPersist(List<FritzMeijerSensorData> sensorDataList, int blockSize) {
        int merged = 0;
        try{
            startTransaction();        
            for (FritzMeijerSensorData sensorData : sensorDataList) {
                merge(sensorData);
                if(merged + 1 % blockSize == 0){
                    commit();
                }
                merged++;
            }
            if(getEntityManager().getTransaction().isActive()){
                commit();
            }
            //TODO: try to find another solution for memory management
            getEntityManager().clear();
        } catch(Exception ex){
            getEntityManager().clear();
            if(blockSize == 1){
                LOG.error(LOGKEY_PROCESSING_ERRORMSG, sensorDataList.get(merged));
                sensorDataList.remove(merged);
                bulkPersist(sensorDataList,1);
            } else {
                bulkPersist(sensorDataList,1);
            }
        }   
    }

     public List <FritzMeijerSensorData> findAllFritzMeijerSensorData(){
        startTransaction();
        Query query = this.getEntityManager().createNamedQuery(FritzMeijerSensorData.Q_FIND_ALL_FRITZMEIJER_SENSORDATA);
        return query.getResultList();
    }

    
}
